@@ -6,7 +6,7 @@ BEGIN {
   $Gentoo::Overlay::Group::INI::AUTHORITY = 'cpan:KENTNL';
 }
 {
-  $Gentoo::Overlay::Group::INI::VERSION = '0.2.0';
+  $Gentoo::Overlay::Group::INI::VERSION = '0.2.1';
 }
 
 # ABSTRACT: Load a list of overlays defined in a configuration file.
@@ -14,7 +14,7 @@ BEGIN {
 use Moose;
 use Path::Class::Dir;
 use File::HomeDir;
-use Gentoo::Overlay::Exceptions;
+use Gentoo::Overlay::Exceptions qw( :all );
 
 
 
@@ -30,8 +30,8 @@ sub _cf_paths {
 ## no critic (RegularExpressions)
 sub _init_cf_paths {
   my $cfg_paths = [
-    Path::Class::Dir->new( File::HomeDir->my_dist_config('Gentoo-Overlay-Group-INI') ),
-    Path::Class::Dir->new( File::HomeDir->my_data )->subdir( '.config', 'Gentoo-Overlay-Group-INI' ),
+    Path::Class::Dir->new( File::HomeDir->my_dist_config( 'Gentoo-Overlay-Group-INI', { create => 1 } ) ),
+    Path::Class::Dir->new( File::HomeDir->my_dist_data( 'Gentoo-Overlay-Group-INI', { create => 1 } ) ),
     Path::Class::Dir->new('/etc/Gentoo-Overlay-Group-INI'),
   ];
 
@@ -167,7 +167,7 @@ Gentoo::Overlay::Group::INI - Load a list of overlays defined in a configuration
 
 =head1 VERSION
 
-version 0.2.0
+version 0.2.1
 
 =head1 SYNOPSIS
 
@@ -178,10 +178,10 @@ Generates a L<< C<Gentoo::Overlay::B<Group>> object|Gentoo::Overlay::Group >> us
 
 Currently, the following paths are checked:
 
-  ~/.perl/Gentoo-Overlay-Group-INI/config.ini
-  ~/.perl/Gentoo-Overlay-Group-INI/Gentoo-Overlay-Group-INI.ini
-  ~/.config/Gentoo-Overlay-Group-INI/config.ini
-  ~/.config/Gentoo-Overlay-Group-INI/Gentoo-Overlay-Group-INI.ini
+  ~/.config/Perl/Gentoo-Overlay-Group-INI/config.ini #  'my_dist_config' dir
+  ~/.config/Perl/Gentoo-Overlay-Group-INI/Gentoo-Overlay-Group-INI.ini
+  ~/.local/share/Perl/dist/Gentoo-Overlay-Group-INI/config.ini  # 'my_dist_data' dir
+  ~/.local/share/Perl/dist/Gentoo-Overlay-Group-INI/Gentoo-Overlay-Group-INI.ini
   /etc/Gentoo-Overlay-Group-INI/config.ini
   /etc/Gentoo-Overlay-Group-INI/Gentoo-Overlay-Group-INI.ini
 
